aboutsummaryrefslogtreecommitdiffstats
path: root/core/nonblocking-application.go
diff options
context:
space:
mode:
authorWei-Ning Huang <w@dexon.org>2018-09-19 18:48:41 +0800
committermissionliao <38416648+missionliao@users.noreply.github.com>2018-09-19 18:48:41 +0800
commit22e70f6da486ed6796a493f25e04679b9afa1439 (patch)
tree41998daa892812957daa58d7fe84d6fd06f4327c /core/nonblocking-application.go
parenta2a733e6f98018cb2ecc4b3982386be8892d7433 (diff)
downloadtangerine-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.tar
tangerine-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.tar.gz
tangerine-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.tar.bz2
tangerine-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.tar.lz
tangerine-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.tar.xz
tangerine-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.tar.zst
tangerine-consensus-22e70f6da486ed6796a493f25e04679b9afa1439.zip
core: rename Notary (Acks) to Witness (#118)
Diffstat (limited to 'core/nonblocking-application.go')
-rw-r--r--core/nonblocking-application.go14
1 files changed, 7 insertions, 7 deletions
diff --git a/core/nonblocking-application.go b/core/nonblocking-application.go
index cb83b17..2226eb0 100644
--- a/core/nonblocking-application.go
+++ b/core/nonblocking-application.go
@@ -44,8 +44,8 @@ type deliverBlockEvent struct {
timestamp time.Time
}
-type notaryAckEvent struct {
- notaryAck *types.NotaryAck
+type witnessAckEvent struct {
+ witnessAck *types.WitnessAck
}
// nonBlockingApplication implements Application and is a decorator for
@@ -100,8 +100,8 @@ func (app *nonBlockingApplication) run() {
app.app.TotalOrderingDeliver(e.blockHashes, e.early)
case deliverBlockEvent:
app.app.DeliverBlock(e.blockHash, e.timestamp)
- case notaryAckEvent:
- app.app.NotaryAckDeliver(e.notaryAck)
+ case witnessAckEvent:
+ app.app.WitnessAckDeliver(e.witnessAck)
default:
fmt.Printf("Unknown event %v.", e)
}
@@ -154,7 +154,7 @@ func (app *nonBlockingApplication) DeliverBlock(
app.addEvent(deliverBlockEvent{blockHash, timestamp})
}
-// NotaryAckDeliver is called when a notary ack is created.
-func (app *nonBlockingApplication) NotaryAckDeliver(notaryAck *types.NotaryAck) {
- app.addEvent(notaryAckEvent{notaryAck})
+// WitnessAckDeliver is called when a witness ack is created.
+func (app *nonBlockingApplication) WitnessAckDeliver(witnessAck *types.WitnessAck) {
+ app.addEvent(witnessAckEvent{witnessAck})
}